testing library

Test utilities for swipe_action_cell.

Import this library in widget tests to access all test helpers:

import 'package:swipe_action_cell/testing.dart';

Activates SwipeAssertions on WidgetTester automatically.

Classes

MockSwipeController
Test double for SwipeController that records method invocations.
SwipeActionCell
A widget that wraps any child and provides spring-based horizontal swipe interaction with asymmetric left/right semantics.
SwipeActionCellState
Mutable state for SwipeActionCell.
SwipeController
Controller for programmatic interaction with a SwipeActionCell.
SwipeProgress
Contains progress information about the current swipe gesture.
SwipeTester
Utility class for simulating swipe gestures in widget tests.
SwipeTestHarness
Wraps a SwipeActionCell with all required test ancestors.

Enums

SwipeDirection
Represents the direction of a swipe gesture.
SwipeState
Represents the current state of the swipe interaction state machine.

Extensions

SwipeAssertions on WidgetTester
Assertion helpers for SwipeActionCell state, added to WidgetTester.