close method
Programmatically closes the attached cell, snapping it back to the resting (origin) position.
No-op (debug assertion in debug mode) when:
Implementation
@override
void close() => _close++;
Programmatically closes the attached cell, snapping it back to the resting (origin) position.
No-op (debug assertion in debug mode) when:
@override
void close() => _close++;