currentProgress property

  1. @override
double get currentProgress
override

The current cumulative progressive value of the attached cell.

Meaningful only when SwipeActionCell.rightSwipeConfig is non-null. Returns 0.0 when no cell is attached or when no right-swipe config is active.

Implementation

@override
double get currentProgress => stubbedProgress;