resetProgress method
Resets the progressive value of the attached cell to RightSwipeConfig.initialValue.
No-op (debug assertion in debug mode) when no cell is attached.
Implementation
@override
void resetProgress() => _resetProgress++;
Resets the progressive value of the attached cell to RightSwipeConfig.initialValue.
No-op (debug assertion in debug mode) when no cell is attached.
@override
void resetProgress() => _resetProgress++;