undo method

  1. @override
bool undo()
override

Sets the progressive value of the attached cell to value, clamped to [RightSwipeConfig.minValue..RightSwipeConfig.maxValue].

Does not fire RightSwipeConfig.onProgressChanged or RightSwipeConfig.onSwipeCompleted. Fires ChangeNotifier listeners when the clamped value differs from the current value.

No-op (debug assertion in debug mode) when no cell is attached. Triggers undo on the attached cell.

Implementation

@override
bool undo() {
  _undo++;
  return false;
}