SwipeTester class

Utility class for simulating swipe gestures in widget tests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dragTo(WidgetTester tester, Finder finder, Offset offset) Future<void>
Drags the cell to the exact offset and pumps exactly one frame.
flingLeft(WidgetTester tester, Finder finder, {double velocity = 1000}) Future<void>
Flings the cell left with the specified velocity.
flingRight(WidgetTester tester, Finder finder, {double velocity = 1000}) Future<void>
Flings the cell right with the specified velocity.
swipeLeft(WidgetTester tester, Finder finder, {double ratio = 0.5}) Future<void>
Drags the cell left by the specified ratio of its width.
swipeRight(WidgetTester tester, Finder finder, {double ratio = 0.5}) Future<void>
Drags the cell right by the specified ratio of its width.
tapAction(WidgetTester tester, Finder cellFinder, int actionIndex) Future<void>
Taps the action button at actionIndex in a revealed cell.